@@ -33,6 +33,9 @@ public:
     void applySettings();
 
 private:
+    QString m_TimeString;
+    QString m_DateString;
+
     int m_Alignment;
     QTimer m_Timer;
     QFont m_TimeFont;
