@@ -24,9 +24,10 @@ LsMediaMetadata::LsMediaMetadata(QString name, SystemPlayer* player) :
     applySettings();
 }
 
-void LsMediaMetadata::paint(QPainter *painter, const QStyleOptionGraphicsItem*,
+void LsMediaMetadata::paint(QPainter *painter, const QStyleOptionGraphicsItem* option,
                             QWidget*)
 {
+    painter->setClipRect(option->exposedRect);
     QString title = m_Metadata.value(SYSTEM_PLAYER_SONG_TITLE).toString();
     if (title.isEmpty())
         title = tr("Unknown title");
@@ -39,7 +40,7 @@ void LsMediaMetadata::paint(QPainter *painter, const QStyleOptionGraphicsItem*,
 
     painter->setFont(m_TitleFont);
     painter->setPen(m_TitleColor);
-    painter->drawText(rect, Qt::AlignTop | m_Alignment | Qt::TextSingleLine, title);
+    painter->drawText(rect, m_Alignment | Qt::TextSingleLine, title);
 
     QFontMetrics fm(m_TitleFont);
     QSize size = fm.size(Qt::TextSingleLine, title);
@@ -47,12 +48,12 @@ void LsMediaMetadata::paint(QPainter *painter, const QStyleOptionGraphicsItem*,
 
     painter->setFont(m_ArtistFont);
     painter->setPen(m_ArtistColor);
-    painter->drawText(rect, Qt::AlignTop | m_Alignment | Qt::TextSingleLine, artist);
+    painter->drawText(rect, m_Alignment | Qt::TextSingleLine, artist);
 }
 
 void LsMediaMetadata::applySettings()
 {
-    m_Alignment = getAlignmentSetting("Alignment", Qt::AlignHCenter);
+    m_Alignment = getAlignmentSetting("Alignment", Qt::AlignHCenter, Qt::AlignTop);
     m_TitleColor = getColorSetting("TitleColor", QColor(255,255,255));
     m_ArtistColor = getColorSetting("ArtistColor", QColor(255,255,255));
 
